aboutsummaryrefslogtreecommitdiffstats
path: root/epan
diff options
context:
space:
mode:
authorMartin Mathieson <martin.mathieson@keysight.com>2020-08-31 16:37:50 +0100
committerMartin Mathieson <martin.mathieson@keysight.com>2020-08-31 16:37:50 +0100
commit4c74caf9ef958886b76f62ca70dbe939fcb51d86 (patch)
tree8227694f7db08b433fea7ac6675842a7c52525a8 /epan
parent2999b7f6b378298001884fa0d95aa108ff0c5f3d (diff)
More spelling fixes, part 2 of 2nd pass of dissectors.
There will likely be one for for this pass. Further improvements to the script are possible, i.e. filtering out (usually filter) strings such as 'onetwothree' - may not be worth it though.
Diffstat (limited to 'epan')
-rw-r--r--epan/dissectors/packet-lustre.c2
-rw-r--r--epan/dissectors/packet-mausb.c4
-rw-r--r--epan/dissectors/packet-megaco.c8
-rw-r--r--epan/dissectors/packet-mswsp.c2
-rw-r--r--epan/dissectors/packet-netflow.c12
-rw-r--r--epan/dissectors/packet-nfapi.c2
-rw-r--r--epan/dissectors/packet-ntp.c2
-rw-r--r--epan/dissectors/packet-opa-fe.c2
-rw-r--r--epan/dissectors/packet-opa-mad.c4
-rw-r--r--epan/dissectors/packet-openflow_v5.c2
-rw-r--r--epan/dissectors/packet-pcep.c20
-rw-r--r--epan/dissectors/packet-pfcp.c26
-rw-r--r--epan/dissectors/packet-pnrp.c2
-rw-r--r--epan/dissectors/packet-ppp.c2
-rw-r--r--epan/dissectors/packet-protobuf.c2
-rw-r--r--epan/dissectors/packet-ptpip.c2
-rw-r--r--epan/dissectors/packet-ptpip.h2
-rw-r--r--epan/dissectors/packet-rlc-nr.c2
-rw-r--r--epan/dissectors/packet-rsl.c2
19 files changed, 50 insertions, 50 deletions
diff --git a/epan/dissectors/packet-lustre.c b/epan/dissectors/packet-lustre.c
index 0f6b785c3d..bdb799c2a1 100644
--- a/epan/dissectors/packet-lustre.c
+++ b/epan/dissectors/packet-lustre.c
@@ -8017,7 +8017,7 @@ proto_register_lustre(void)
{ &hf_lustre_ldlm_intent_opc_open,
{ "open", "lustre.ldlm_intent.opc_open", FT_BOOLEAN, 32, TFS(&lnet_flags_set_truth), IT_OPEN, NULL, HFILL } },
{ &hf_lustre_ldlm_intent_opc_creat,
- { "creat", "lustre.ldlm_intent.opc_creat", FT_BOOLEAN, 32, TFS(&lnet_flags_set_truth), IT_CREAT , NULL, HFILL } },
+ { "create", "lustre.ldlm_intent.opc_create", FT_BOOLEAN, 32, TFS(&lnet_flags_set_truth), IT_CREAT , NULL, HFILL } },
{ &hf_lustre_ldlm_intent_opc_readdir,
{ "readdir", "lustre.ldlm_intent.opc_readdir", FT_BOOLEAN, 32, TFS(&lnet_flags_set_truth), IT_READDIR , NULL, HFILL } },
{ &hf_lustre_ldlm_intent_opc_getattr,
diff --git a/epan/dissectors/packet-mausb.c b/epan/dissectors/packet-mausb.c
index 26e57baa48..57393f22ad 100644
--- a/epan/dissectors/packet-mausb.c
+++ b/epan/dissectors/packet-mausb.c
@@ -405,8 +405,8 @@ static const value_string mausb_status_string[] = {
{ 140, "TRANSFER_TRANSACTION_ERROR" },
{ 141, "TRANSFER_SHORT_TRANSFER" },
{ 142, "TRANSFER_CANCELLED" },
- { 143, "INSUFFICENT_RESOURCES" },
- { 144, "NOT_SUFFICENT_BANDWIDTH" },
+ { 143, "INSUFFICIENT_RESOURCES" },
+ { 144, "NOT_SUFFICIENT_BANDWIDTH" },
{ 145, "INTERNAL_ERROR" },
{ 146, "DATA_OVERRUN" },
{ 147, "DEVICE_NOT_ACCESSED" },
diff --git a/epan/dissectors/packet-megaco.c b/epan/dissectors/packet-megaco.c
index 5c6a1f7511..d20280b24d 100644
--- a/epan/dissectors/packet-megaco.c
+++ b/epan/dissectors/packet-megaco.c
@@ -54,7 +54,7 @@ void proto_reg_handoff_megaco(void);
#define PORT_MEGACO_TXT 2944
#define PORT_MEGACO_BIN 2945
-static pref_t *sip_hide_generatd_call_ids;
+static pref_t *sip_hide_generated_call_ids;
/* Define the megaco proto */
@@ -3033,10 +3033,10 @@ dissect_megaco_LocalRemotedescriptor(tvbuff_t *tvb, proto_tree *megaco_mediadesc
if ((context != 0) && (context < 0xfffffffe)) {
setup_info.hf_id = hf_megaco_Context;
setup_info.hf_type = SDP_TRACE_ID_HF_TYPE_GUINT32;
- if (!sip_hide_generatd_call_ids) {
+ if (!sip_hide_generated_call_ids) {
setup_info.add_hidden = FALSE;
} else {
- setup_info.add_hidden = prefs_get_bool_value(sip_hide_generatd_call_ids, pref_current);
+ setup_info.add_hidden = prefs_get_bool_value(sip_hide_generated_call_ids, pref_current);
}
setup_info.trace_id.num = context;
message_info.data = &setup_info;
@@ -3934,7 +3934,7 @@ proto_reg_handoff_megaco(void)
exported_pdu_tap = find_tap_id(EXPORT_PDU_TAP_NAME_LAYER_7);
- sip_hide_generatd_call_ids = prefs_find_preference(prefs_find_module("sip"), "hide_generatd_call_id");
+ sip_hide_generated_call_ids = prefs_find_preference(prefs_find_module("sip"), "hide_generated_call_id");
}
diff --git a/epan/dissectors/packet-mswsp.c b/epan/dissectors/packet-mswsp.c
index e965796ba3..225736d2f4 100644
--- a/epan/dissectors/packet-mswsp.c
+++ b/epan/dissectors/packet-mswsp.c
@@ -6451,7 +6451,7 @@ proto_register_mswsp(void)
{
&hf_mswsp_bool_options_async,
{
- "eAsynchronous", "mswsp.CPMCreateQuery.RowSetProperties.uBooleanOptions.eAsyncronous",
+ "eAsynchronous", "mswsp.CPMCreateQuery.RowSetProperties.uBooleanOptions.eAsynchronous",
FT_BOOLEAN, 32, NULL, eAsynchronous, "The client will not wait for execution completion", HFILL
}
},
diff --git a/epan/dissectors/packet-netflow.c b/epan/dissectors/packet-netflow.c
index 10d36dec3e..a034308622 100644
--- a/epan/dissectors/packet-netflow.c
+++ b/epan/dissectors/packet-netflow.c
@@ -1728,7 +1728,7 @@ static const value_string v10_template_types_gigamon[] = {
{ 104, "SslCertificateSubject" },
{ 105, "SslCertificateValidNotBefore" },
{ 106, "SslCertificateValidNotAfter" },
- { 107, "SslCetificateSerialNumber" },
+ { 107, "SslCertificateSerialNumber" },
{ 108, "SslCertificateSignatureAlgorithm" },
{ 109, "SslCertificateSubjectPubAlgorithm" },
{ 110, "SslCertificateSubjectPubKeySize" },
@@ -3394,7 +3394,7 @@ static int hf_pie_gigamon_sslcertificateissuer = -1;
static int hf_pie_gigamon_sslcertificatesubject = -1;
static int hf_pie_gigamon_sslcertificatevalidnotbefore = -1;
static int hf_pie_gigamon_sslcertificatevalidnotafter = -1;
-static int hf_pie_gigamon_sslcetificateserialnumber = -1;
+static int hf_pie_gigamon_sslcertificateserialnumber = -1;
static int hf_pie_gigamon_sslcertificatesignaturealgorithm = -1;
static int hf_pie_gigamon_sslcertificatesubjectpubalgorithm = -1;
static int hf_pie_gigamon_sslcertificatesubjectpubkeysize = -1;
@@ -10663,7 +10663,7 @@ dissect_v9_v10_pdu_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *pdutree,
break;
case ((VENDOR_GIGAMON << 16) | 107):
- ti = proto_tree_add_item(pdutree, hf_pie_gigamon_sslcetificateserialnumber,
+ ti = proto_tree_add_item(pdutree, hf_pie_gigamon_sslcertificateserialnumber,
tvb, offset, length, ENC_NA);
break;
@@ -17252,7 +17252,7 @@ proto_register_netflow(void)
{&hf_pie_ixia_l7_application_id,
{"L7 Application ID", "cflow.pie.ixia.l7-application-id",
FT_UINT32, BASE_DEC, NULL, 0x0,
- "Application Identication number. Dynamically detected, so unique to each exporter", HFILL}
+ "Application Identification number. Dynamically detected, so unique to each exporter", HFILL}
},
/* ixia, 3054 / 111 */
{&hf_pie_ixia_l7_application_name,
@@ -18350,8 +18350,8 @@ proto_register_netflow(void)
NULL, HFILL}
},
/* gigamon, 26866 / 107 */
- {&hf_pie_gigamon_sslcetificateserialnumber,
- {"SslCetificateSerialNumber", "cflow.pie.gigamon.sslcetificateserialnumber",
+ {&hf_pie_gigamon_sslcertificateserialnumber,
+ {"SslCertificateSerialNumber", "cflow.pie.gigamon.sslcertificateserialnumber",
FT_BYTES, BASE_NONE, NULL, 0x0,
NULL, HFILL}
},
diff --git a/epan/dissectors/packet-nfapi.c b/epan/dissectors/packet-nfapi.c
index 649536d92e..c03378cfd1 100644
--- a/epan/dissectors/packet-nfapi.c
+++ b/epan/dissectors/packet-nfapi.c
@@ -1864,7 +1864,7 @@ static void dissect_pnf_phy_rel12_instance_value(ptvcursor_t * ptvc, packet_info
item = ptvcursor_add_ret_uint(ptvc, hi_nfapi_alternative_tbs_indices, 2, ENC_BIG_ENDIAN, &test_value);
if (test_value > 1)
{
- expert_add_info_format(pinfo, item, &ei_invalid_range, "Invalid alternative tbs indicies supported value [0..1]");
+ expert_add_info_format(pinfo, item, &ei_invalid_range, "Invalid alternative tbs indices supported value [0..1]");
}
}
diff --git a/epan/dissectors/packet-ntp.c b/epan/dissectors/packet-ntp.c
index 62c7348278..503fdcc999 100644
--- a/epan/dissectors/packet-ntp.c
+++ b/epan/dissectors/packet-ntp.c
@@ -3435,7 +3435,7 @@ proto_register_ntp(void)
"Overflows", "ntp.priv.mode7.overflows", FT_UINT32, BASE_DEC,
NULL, 0, NULL, HFILL }},
{ &hf_ntppriv_mode7_xmtcalls, {
- "Trasmitted calls", "ntp.priv.mode7.xmtcalls", FT_UINT32, BASE_DEC,
+ "Transmitted calls", "ntp.priv.mode7.xmtcalls", FT_UINT32, BASE_DEC,
NULL, 0, NULL, HFILL }},
{ &hf_ntppriv_mode7_rflags, {
"Rflags", "ntp.priv.mode7.rflags", FT_UINT16, BASE_DEC,
diff --git a/epan/dissectors/packet-opa-fe.c b/epan/dissectors/packet-opa-fe.c
index 02d52e6885..402c9c8edf 100644
--- a/epan/dissectors/packet-opa-fe.c
+++ b/epan/dissectors/packet-opa-fe.c
@@ -130,7 +130,7 @@ void proto_register_opa_fe(void)
};
proto_opa_fe = proto_register_protocol(
- "Intel Omni-Path FE Header - Omni-Path Fabric Excutive Header",
+ "Intel Omni-Path FE Header - Omni-Path Fabric Executive Header",
"OPA FE", "opa.fe");
opa_fe_handle = register_dissector("opa.fe", dissect_opa_fe, proto_opa_fe);
diff --git a/epan/dissectors/packet-opa-mad.c b/epan/dissectors/packet-opa-mad.c
index f823bbb1dc..465cf37b87 100644
--- a/epan/dissectors/packet-opa-mad.c
+++ b/epan/dissectors/packet-opa-mad.c
@@ -10459,7 +10459,7 @@ void proto_register_opa_mad(void)
FT_UINT16, BASE_HEX, NULL, 0x0, NULL, HFILL }
},
{ &hf_opa_BufferControlTable_TxDedicatedLimit, {
- "Tx Dedictated Limit", "opa.buffercontroltable.txdedicatedlimit",
+ "Tx Dedicated Limit", "opa.buffercontroltable.txdedicatedlimit",
FT_UINT16, BASE_HEX, NULL, 0x0, NULL, HFILL }
},
{ &hf_opa_BufferControlTable_TxSharedLimit, {
@@ -13421,7 +13421,7 @@ void proto_register_opa_mad(void)
FT_UINT8, BASE_HEX, NULL, 0x0, NULL, HFILL }
},
{ &hf_opa_VFInfoRecord_reserved7, {
- "Rezerved (24 Bytes)", "opa.vfinforecord.reserved7",
+ "Reserved (24 Bytes)", "opa.vfinforecord.reserved7",
FT_NONE, BASE_NONE, NULL, 0x0, NULL, HFILL }
},
/* QuarantinedNodeRecord */
diff --git a/epan/dissectors/packet-openflow_v5.c b/epan/dissectors/packet-openflow_v5.c
index 1374ec7fe0..c73991d45b 100644
--- a/epan/dissectors/packet-openflow_v5.c
+++ b/epan/dissectors/packet-openflow_v5.c
@@ -9636,7 +9636,7 @@ proto_register_openflow_v5(void)
},
{ &ei_openflow_v5_multipart_request_undecoded,
{ "openflow_v5.multipart_request.undecoded", PI_UNDECODED, PI_NOTE,
- "Unknown multipart reqeuest body.", EXPFILL }
+ "Unknown multipart request body.", EXPFILL }
},
{ &ei_openflow_v5_queue_stats_prop_undecoded,
{ "openflow_v5.queue_stats_prop.undecoded", PI_UNDECODED, PI_NOTE,
diff --git a/epan/dissectors/packet-pcep.c b/epan/dissectors/packet-pcep.c
index 57cf58b331..08ef77703e 100644
--- a/epan/dissectors/packet-pcep.c
+++ b/epan/dissectors/packet-pcep.c
@@ -622,12 +622,12 @@ static int hf_pcep_obj_srp_flags = -1;
static int hf_pcep_obj_srp_flags_r = -1;
static int hf_pcep_obj_srp_id_number = -1;
static int hf_pcep_symbolic_path_name = -1;
-static int hf_pcep_ipv4_lsp_id_tunnnel_sender_address = -1;
+static int hf_pcep_ipv4_lsp_id_tunnel_sender_address = -1;
static int hf_pcep_ipv4_lsp_id_lsp_id = -1;
static int hf_pcep_ipv4_lsp_id_tunnel_id = -1;
static int hf_pcep_ipv4_lsp_id_extended_tunnel_id = -1;
static int hf_pcep_ipv4_lsp_id_tunnel_endpoint_address = -1;
-static int hf_pcep_ipv6_lsp_id_tunnnel_sender_address = -1;
+static int hf_pcep_ipv6_lsp_id_tunnel_sender_address = -1;
static int hf_pcep_ipv6_lsp_id_lsp_id = -1;
static int hf_pcep_ipv6_lsp_id_tunnel_id = -1;
static int hf_pcep_ipv6_lsp_id_extended_tunnel_id = -1;
@@ -1442,7 +1442,7 @@ dissect_pcep_tlvs(proto_tree *pcep_obj, tvbuff_t *tvb, int offset, gint length,
break;
case 18: /* IPV4-LSP-IDENTIFIERS TLV */
- proto_tree_add_item(tlv, hf_pcep_ipv4_lsp_id_tunnnel_sender_address, tvb, offset+4+j, 4, ENC_BIG_ENDIAN);
+ proto_tree_add_item(tlv, hf_pcep_ipv4_lsp_id_tunnel_sender_address, tvb, offset+4+j, 4, ENC_BIG_ENDIAN);
proto_tree_add_item(tlv, hf_pcep_ipv4_lsp_id_lsp_id, tvb, offset+4+j + 4, 2, ENC_BIG_ENDIAN);
proto_tree_add_item(tlv, hf_pcep_ipv4_lsp_id_tunnel_id, tvb, offset+4+j + 6, 2, ENC_BIG_ENDIAN);
proto_tree_add_item(tlv, hf_pcep_ipv4_lsp_id_extended_tunnel_id, tvb, offset+4+j + 8, 4, ENC_BIG_ENDIAN);
@@ -1450,7 +1450,7 @@ dissect_pcep_tlvs(proto_tree *pcep_obj, tvbuff_t *tvb, int offset, gint length,
break;
case 19: /* IPV6-LSP-IDENTIFIERS TLV */
- proto_tree_add_item(tlv, hf_pcep_ipv6_lsp_id_tunnnel_sender_address, tvb, offset+4+j, 16, ENC_NA);
+ proto_tree_add_item(tlv, hf_pcep_ipv6_lsp_id_tunnel_sender_address, tvb, offset+4+j, 16, ENC_NA);
proto_tree_add_item(tlv, hf_pcep_ipv6_lsp_id_lsp_id, tvb, offset+4+j + 16, 2, ENC_BIG_ENDIAN);
proto_tree_add_item(tlv, hf_pcep_ipv6_lsp_id_tunnel_id, tvb, offset+4+j + 18, 2, ENC_BIG_ENDIAN);
proto_tree_add_item(tlv, hf_pcep_ipv6_lsp_id_extended_tunnel_id, tvb, offset+4+j + 20, 16, ENC_BIG_ENDIAN);
@@ -5538,8 +5538,8 @@ proto_register_pcep(void)
FT_STRING, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
- { &hf_pcep_ipv4_lsp_id_tunnnel_sender_address,
- { "IPv4 Tunnel Sender Address", "pcep.tlv.ipv4-lsp-id.tunnnel-sender-addr",
+ { &hf_pcep_ipv4_lsp_id_tunnel_sender_address,
+ { "IPv4 Tunnel Sender Address", "pcep.tlv.ipv4-lsp-id.tunnel-sender-addr",
FT_IPv4, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
@@ -5559,12 +5559,12 @@ proto_register_pcep(void)
NULL, HFILL }
},
{ &hf_pcep_ipv4_lsp_id_tunnel_endpoint_address,
- { "IPv4 Tunnel Endpoint Address", "pcep.tlv.ipv4-lsp-id.tunnnel-endpoint-addr",
+ { "IPv4 Tunnel Endpoint Address", "pcep.tlv.ipv4-lsp-id.tunnel-endpoint-addr",
FT_IPv4, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
- { &hf_pcep_ipv6_lsp_id_tunnnel_sender_address,
- { "IPv6 Tunnel Sender Address", "pcep.tlv.ipv6-lsp-id.tunnnel-sender-addr",
+ { &hf_pcep_ipv6_lsp_id_tunnel_sender_address,
+ { "IPv6 Tunnel Sender Address", "pcep.tlv.ipv6-lsp-id.tunnel-sender-addr",
FT_IPv6, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
@@ -5584,7 +5584,7 @@ proto_register_pcep(void)
NULL, HFILL }
},
{ &hf_pcep_ipv6_lsp_id_tunnel_endpoint_address,
- { "IPv6 Tunnel Endpoint Address", "pcep.tlv.ipv6-lsp-id.tunnnel-endpoint-addr",
+ { "IPv6 Tunnel Endpoint Address", "pcep.tlv.ipv6-lsp-id.tunnel-endpoint-addr",
FT_IPv6, BASE_NONE, NULL, 0x0,
NULL, HFILL }
},
diff --git a/epan/dissectors/packet-pnrp.c b/epan/dissectors/packet-pnrp.c
index f84fc43b75..6adba49ef6 100644
--- a/epan/dissectors/packet-pnrp.c
+++ b/epan/dissectors/packet-pnrp.c
@@ -1348,7 +1348,7 @@ void proto_register_pnrp(void)
{ "Hashed Nonce", "pnrp.segment.hashednonce", FT_BYTES, BASE_NONE, NULL, 0x0,
NULL, HFILL }},
{ &hf_pnrp_message_idArray_NumEntries,
- { "Number of Entries", "pnrp.segment.idArray.NumEnries", FT_UINT16, BASE_DEC, NULL, 0x0,
+ { "Number of Entries", "pnrp.segment.idArray.NumEntries", FT_UINT16, BASE_DEC, NULL, 0x0,
NULL, HFILL }},
{ &hf_pnrp_message_idArray_Length,
{ "Length of Array", "pnrp.segment.idArray.Length", FT_UINT16, BASE_DEC, NULL, 0x0,
diff --git a/epan/dissectors/packet-ppp.c b/epan/dissectors/packet-ppp.c
index e0f50f7d09..45e40b4ea2 100644
--- a/epan/dissectors/packet-ppp.c
+++ b/epan/dissectors/packet-ppp.c
@@ -6578,7 +6578,7 @@ proto_register_mp(void)
10, &mp_max_fragments);
prefs_register_uint_preference(mp_module, "fragment_aging",
"Max unreassembled fragment age",
- "Age off unreassmbled fragments after this many packets",
+ "Age off unreassembled fragments after this many packets",
10, &mp_fragment_aging);
}
diff --git a/epan/dissectors/packet-protobuf.c b/epan/dissectors/packet-protobuf.c
index bcae511841..0a04fc5dcd 100644
--- a/epan/dissectors/packet-protobuf.c
+++ b/epan/dissectors/packet-protobuf.c
@@ -1551,7 +1551,7 @@ proto_register_protobuf(void)
prefs_register_bool_preference(protobuf_module, "pbf_as_hf",
"Dissect Protobuf fields as Wireshark fields.",
"If Protobuf messages and fields are defined in loaded .proto files,"
- " they will be dissected as wireshark fields if this option is turnned on."
+ " they will be dissected as wireshark fields if this option is turned on."
" The names of all these wireshark fields will be prefixed with \"pbf.\" (for fields)"
" or \"pbm.\" (for messages) followed by their full names in the .proto files.",
&pbf_as_hf);
diff --git a/epan/dissectors/packet-ptpip.c b/epan/dissectors/packet-ptpip.c
index 03e96ade82..586433c06e 100644
--- a/epan/dissectors/packet-ptpip.c
+++ b/epan/dissectors/packet-ptpip.c
@@ -188,7 +188,7 @@ static const value_string ptp_opcode_canon_names[] = {
{ PTP_OC_CANON_TerminateDirectTransfer, "CANON_TerminateDirectTransfer" },
{ PTP_OC_CANON_SendObjectInfoByPath, "CANON_SendObjectInfoByPath" },
{ PTP_OC_CANON_SendObjectByPath, "CANON_SendObjectByPath" },
- { PTP_OC_CANON_InitiateDirectTansferEx, "CANON_InitiateDirectTansferEx" },
+ { PTP_OC_CANON_InitiateDirectTransferEx, "CANON_InitiateDirectTransferEx" },
{ PTP_OC_CANON_GetAncillaryObjectHandles, "CANON_GetAncillaryObjectHandles" },
{ PTP_OC_CANON_GetTreeInfo, "CANON_GetTreeInfo" },
{ PTP_OC_CANON_GetTreeSize, "CANON_GetTreeSize" },
diff --git a/epan/dissectors/packet-ptpip.h b/epan/dissectors/packet-ptpip.h
index 263552c6b4..7747b335e9 100644
--- a/epan/dissectors/packet-ptpip.h
+++ b/epan/dissectors/packet-ptpip.h
@@ -113,7 +113,7 @@ typedef enum {
PTP_OC_CANON_TerminateDirectTransfer = 0x9023,
PTP_OC_CANON_SendObjectInfoByPath = 0x9024,
PTP_OC_CANON_SendObjectByPath = 0x9025,
- PTP_OC_CANON_InitiateDirectTansferEx = 0x9026,
+ PTP_OC_CANON_InitiateDirectTransferEx = 0x9026,
PTP_OC_CANON_GetAncillaryObjectHandles = 0x9027,
PTP_OC_CANON_GetTreeInfo = 0x9028,
PTP_OC_CANON_GetTreeSize = 0x9029,
diff --git a/epan/dissectors/packet-rlc-nr.c b/epan/dissectors/packet-rlc-nr.c
index 14b6965d37..e44236f060 100644
--- a/epan/dissectors/packet-rlc-nr.c
+++ b/epan/dissectors/packet-rlc-nr.c
@@ -1674,7 +1674,7 @@ void proto_register_rlc_nr(void)
prefs_register_bool_preference(rlc_nr_module, "reassemble_um_frames",
"Try to reassemble UM frames",
"N.B. This should be considered experimental/incomplete, in that it doesn't try to discard reassembled state "
- "when reestablishmenment happens, or in certain packet-loss cases",
+ "when reestablishment happens, or in certain packet-loss cases",
&global_rlc_nr_reassemble_um_pdus);
ue_parameters_tree = wmem_tree_new_autoreset(wmem_epan_scope(), wmem_file_scope());
diff --git a/epan/dissectors/packet-rsl.c b/epan/dissectors/packet-rsl.c
index dfbaf70448..786aea8bbf 100644
--- a/epan/dissectors/packet-rsl.c
+++ b/epan/dissectors/packet-rsl.c
@@ -2142,7 +2142,7 @@ static const value_string rsl_cause_value_vals[] = {
{ 0x24, "ACCH overload" },
{ 0x25, "processor overload" },
/* 0x26: "reserved for international use" */
- { 0x27, "BTS not equiped" },
+ { 0x27, "BTS not equipped" },
{ 0x28, "remote transcoder issue" },
/* 0x29..0x2b: "reserved for international use" */
/* 0x2c..0x2e: "reserved for national use" */
diff --git a/epan/dissectors/packet-pfcp.c b/epan/dissectors/packet-pfcp.c
index 73bcde6a7a..34645ce933 100644
--- a/epan/dissectors/packet-pfcp.c
+++ b/epan/dissectors/packet-pfcp.c
@@ -103,8 +103,8 @@ static int hf_pfcp_f_teid_ipv6 = -1;
static int hf_pfcp_network_instance = -1;
static int hf_pfcp_pdn_type = -1;
static int hf_pfcp_failed_rule_id_type = -1;
-static int hf_pfcp_time_qouta_mechanism_bti_type = -1;
-static int hf_pfcp_time_qouta_mechanism_bti = -1;
+static int hf_pfcp_time_quota_mechanism_bti_type = -1;
+static int hf_pfcp_time_quota_mechanism_bti = -1;
static int hf_pfcp_multiplier_value_digits = -1;
static int hf_pfcp_multiplier_exponent = -1;
static int hf_pfcp_aggregated_urr_id_ie_urr_id = -1;
@@ -4947,29 +4947,29 @@ dissect_pfcp_failed_rule_id(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *t
/*
* 8.2.81 Time Quota Mechanism
*/
-static const value_string pfcp_time_qouta_mechanism_bti_type_vals[] = {
+static const value_string pfcp_time_quota_mechanism_bti_type_vals[] = {
{ 0, "CTP" },
{ 1, "DTP" },
{ 0, NULL }
};
static void
-dissect_pfcp_time_qouta_mechanism(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, proto_item *item _U_, guint16 length, guint8 message_type _U_, pfcp_session_args_t *args _U_)
+dissect_pfcp_time_quota_mechanism(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree, proto_item *item _U_, guint16 length, guint8 message_type _U_, pfcp_session_args_t *args _U_)
{
int offset = 0;
guint32 bti_type;
/* Octet 5 BIT Type */
- proto_tree_add_item_ret_uint(tree, hf_pfcp_time_qouta_mechanism_bti_type, tvb, offset, 1, ENC_BIG_ENDIAN, &bti_type);
+ proto_tree_add_item_ret_uint(tree, hf_pfcp_time_quota_mechanism_bti_type, tvb, offset, 1, ENC_BIG_ENDIAN, &bti_type);
offset++;
- proto_item_append_text(item, "%s", val_to_str_const(bti_type, pfcp_time_qouta_mechanism_bti_type_vals, "Unknown"));
+ proto_item_append_text(item, "%s", val_to_str_const(bti_type, pfcp_time_quota_mechanism_bti_type_vals, "Unknown"));
/* Base Time Interval
* The Base Time Interval, shall be encoded as an Unsigned32
* as specified in subclause 7.2.29 of 3GPP TS 32.299
*/
- proto_tree_add_item(tree, hf_pfcp_time_qouta_mechanism_bti, tvb, offset, 4, ENC_BIG_ENDIAN);
+ proto_tree_add_item(tree, hf_pfcp_time_quota_mechanism_bti, tvb, offset, 4, ENC_BIG_ENDIAN);
offset += 4;
if (offset < length) {
@@ -7610,7 +7610,7 @@ static const pfcp_ie_t pfcp_ies[] = {
/* 112 */ { dissect_pfcp_graceful_release_period }, /* Graceful Release Period Extendable / Subclause 8.2.78 */
/* 113 */ { dissect_pfcp_pdn_type }, /* PDN Type Fixed Length / Subclause 8.2.79 */
/* 114 */ { dissect_pfcp_failed_rule_id }, /* Failed Rule ID Extendable / Subclause 8.2.80 */
/* 115 */ { dissect_pfcp_time_qouta_mechanism }, /* Time Quota Mechanism Extendable / Subclause 8.2.81 */
/* 116 */ { dissect_pfcp_user_plane_ip_resource_infomation }, /* User Plane IP Resource Information Extendable / Subclause 8.2.82 */
/* 117 */ { dissect_pfcp_user_plane_inactivity_timer }, /* User Plane Inactivity Timer Extendable / Subclause 8.2.83 */
/* 118 */ { dissect_pfcp_aggregated_urrs }, /* Aggregated URRs Extendable / Table 7.5.2.4-2 */
@@ -9163,13 +9163,13 @@ proto_register_pfcp(void)
FT_UINT8, BASE_DEC, VALS(pfcp_failed_rule_id_type_vals), 0x7,
NULL, HFILL }
},
- { &hf_pfcp_time_qouta_mechanism_bti_type,
- { "Base Time Interval Type", "pfcp.time_qouta_mechanism_bti_type",
- FT_UINT8, BASE_DEC, VALS(pfcp_time_qouta_mechanism_bti_type_vals), 0x3,
+ { &hf_pfcp_time_quota_mechanism_bti_type,
+ { "Base Time Interval Type", "pfcp.time_quota_mechanism_bti_type",
+ FT_UINT8, BASE_DEC, VALS(pfcp_time_quota_mechanism_bti_type_vals), 0x3,
NULL, HFILL }
},
- { &hf_pfcp_time_qouta_mechanism_bti,
- { "Base Time Interval", "pfcp.time_qouta_mechanism_bti",
+ { &hf_pfcp_time_quota_mechanism_bti,
+ { "Base Time Interval", "pfcp.time_quota_mechanism_bti",
FT_UINT32, BASE_DEC, NULL, 0x0,
NULL, HFILL }
},
@@ -7610,7 +7610,7 @@ static const pfcp_ie_t pfcp_ies[] = {
/* 113 */ { dissect_pfcp_pdn_type }, /* PDN Type Fixed Length / Subclause 8.2.79 */
/* 114 */ { dissect_pfcp_failed_rule_id }, /* Failed Rule ID Extendable / Subclause 8.2.80 */
-/* 115 */ { dissect_pfcp_time_qouta_mechanism }, /* Time Quota Mechanism Extendable / Subclause 8.2.81 */
+/* 115 */ { dissect_pfcp_time_quota_mechanism }, /* Time Quota Mechanism Extendable / Subclause 8.2.81 */
/* 116 */ { dissect_pfcp_user_plane_ip_resource_infomation }, /* User Plane IP Resource Information Extendable / Subclause 8.2.82 */
/* 117 */ { dissect_pfcp_user_plane_inactivity_timer }, /* User Plane Inactivity Timer Extendable / Subclause 8.2.83 */